(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue'), require('uuid')) :
    typeof define === 'function' && define.amd ? define(['exports', 'vue', 'uuid'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.BootstrapVue = {}, global.Vue, global.uuid));
})(this, (function (exports, vue, uuid) { 'use strict';

    var templateString = (template, value) => {
        const values = Array.isArray(value) ? value : [value];
        let result = undefined;
        if (!values.some(v => v === undefined)) {
            let templated = template;
            values.forEach((v, i) => {
                templated = templated.replace(`{${i}}`, v);
            });
            result = templated;
        }
        return result;
    };

    var useStringTemplate = (template, value) => ({
        templatedString: vue.computed(() => templateString(vue.unref(template), vue.unref(value))),
    });

    var useFlush = (flush, classTemplate) => {
        const { templatedString } = useStringTemplate(classTemplate, 'flush');
        const flushClass = vue.computed(() => vue.unref(flush) ? vue.unref(templatedString) : undefined);
        return { flushClass };
    };
    const flushProps = {
        flush: {
            type: Boolean,
            default: false,
        },
    };

    const idProps = {
        id: {
            type: String,
            /**
             * ID's that start with a numeric value are considered invalid query
             * selectors, thus prefix it with something non-numeric.
             */
            default: () => `owow-${uuid.v4()}`,
        },
    };

    var useClasses = (values) => ({
        classes: vue.computed(() => vue.unref(values)
            .filter((v, i, s) => !!v && s.indexOf(v) === i)),
    });

    const _hoisted_1$m = ["id"];
    var script$D = /*#__PURE__*/ vue.defineComponent({
        __name: 'Accordion',
        props: Object.assign(Object.assign({}, flushProps), idProps),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                useFlush(props.flush, 'accordion-{0}').flushClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    id: _ctx.id,
                    class: vue.normalizeClass(["accordion", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "default", { parentId: _ctx.id })
                ], 10 /* CLASS, PROPS */, _hoisted_1$m));
            };
        }
    });

    script$D.__file = "src/components/Accordion/Accordion.vue";

    const _hoisted_1$l = { class: "accordion-item" };
    const _hoisted_2$e = ["data-bs-target"];
    const _hoisted_3$8 = ["id", "data-bs-parent"];
    var script$C = /*#__PURE__*/ vue.defineComponent({
        __name: 'AccordionItem',
        props: Object.assign(Object.assign({ bodyClass: {
                type: [String, Array, Object],
                default: undefined,
            }, buttonClass: {
                type: [String, Array, Object],
                default: undefined,
            }, collapseClass: {
                type: [String, Array, Object],
                default: undefined,
            }, header: {
                type: String,
                default: undefined,
            }, headerClass: {
                type: [String, Array, Object],
                default: undefined,
            }, headerTag: {
                type: String,
                default: 'h2',
            } }, idProps), { parentId: {
                type: String,
                default: undefined,
            } }),
        setup(__props) {
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$l, [
                    (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.headerTag), {
                        class: vue.normalizeClass(["accordion-header", __props.headerClass])
                    }, {
                        default: vue.withCtx(() => [
                            vue.createElementVNode("button", {
                                class: vue.normalizeClass(["accordion-button collapsed", __props.buttonClass]),
                                "data-bs-toggle": "collapse",
                                "data-bs-target": `#${_ctx.id}`
                            }, [
                                vue.renderSlot(_ctx.$slots, "header", {}, () => [
                                    vue.createTextVNode(vue.toDisplayString(__props.header), 1 /* TEXT */)
                                ])
                            ], 10 /* CLASS, PROPS */, _hoisted_2$e)
                        ]),
                        _: 3 /* FORWARDED */
                    }, 8 /* PROPS */, ["class"])),
                    vue.createElementVNode("div", {
                        id: `${_ctx.id}`,
                        class: vue.normalizeClass(["accordion-collapse collapse", __props.collapseClass]),
                        "data-bs-parent": __props.parentId ? `#${__props.parentId}` : undefined
                    }, [
                        vue.createElementVNode("div", {
                            class: vue.normalizeClass(["accordion-body", __props.bodyClass])
                        }, [
                            vue.renderSlot(_ctx.$slots, "default")
                        ], 2 /* CLASS */)
                    ], 10 /* CLASS, PROPS */, _hoisted_3$8)
                ]));
            };
        }
    });

    script$C.__file = "src/components/AccordionItem/AccordionItem.vue";

    const useBootstrapEmits = (element, events, emit, typeName) => {
        vue.onMounted(() => {
            events.forEach((event) => {
                const eventCallback = () => emit(event);
                element.value.addEventListener(`${event}.bs.${typeName}`, eventCallback);
            });
        });
    };

    /******************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */

    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }

    const useBootstrap = () => {
        const bootstrap = vue.ref();
        vue.onMounted(() => __awaiter(void 0, void 0, void 0, function* () { return document && (bootstrap.value = yield import('bootstrap')); }));
        return bootstrap;
    };

    // TODO: Better typehinting
    const useBootstrapInstance = (type, element, options = {}) => {
        const bootstrap = useBootstrap();
        const bsInstance = vue.ref();
        vue.watch(bootstrap, () => {
            var _a, _b;
            if (element.value) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                bsInstance.value = (_a = bootstrap.value) === null || _a === void 0 ? void 0 : _a[type].getOrCreateInstance(((_b = element.value) === null || _b === void 0 ? void 0 : _b.$el) || element.value, options);
            }
        });
        return { bootstrap, bsInstance };
    };

    const variants = ['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark', 'link'];
    var useVariant = (variant, classTemplate) => {
        const { templatedString } = useStringTemplate(classTemplate, variant);
        return { variantClass: templatedString };
    };
    const variantProp = (defaultValue = 'primary') => {
        return {
            type: String,
            default: defaultValue,
            validator: (v) => v ? variants.includes(v) : true,
        };
    };
    const variantProps = {
        variant: variantProp(),
    };

    const alertEvents = ['close', 'closed'];
    var script$B = /*#__PURE__*/ vue.defineComponent({
        __name: 'Alert',
        props: variantProps,
        setup(__props, { expose, emit }) {
            const props = __props;
            const alert = vue.ref();
            useBootstrapEmits(alert, alertEvents, emit, 'alert');
            const { bsInstance: bsAlert } = useBootstrapInstance('Alert', alert);
            const { classes } = useClasses(vue.computed(() => [
                useVariant(props.variant, 'alert-{0}').variantClass.value,
            ]));
            expose({ bsAlert });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    ref_key: "alert",
                    ref: alert,
                    class: vue.normalizeClass(["alert", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$B.__file = "src/components/Alert/Alert.vue";

    var script$A = /*#__PURE__*/ vue.defineComponent({
        __name: 'Badge',
        props: Object.assign({ pill: {
                type: Boolean,
                default: false,
            } }, variantProps),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                vue.computed(() => props.pill ? 'rounded-pill' : undefined).value,
                useVariant(props.variant, 'bg-{0}').variantClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(["badge", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$A.__file = "src/components/Badge/Badge.vue";

    const _hoisted_1$k = { class: "breadcrumb" };

    function render$1(_ctx, _cache) {
      return (vue.openBlock(), vue.createElementBlock("nav", null, [
        vue.createElementVNode("ol", _hoisted_1$k, [
          vue.renderSlot(_ctx.$slots, "default")
        ])
      ]))
    }

    const script$z = {};


    script$z.render = render$1;
    script$z.__file = "src/components/Breadcrumb/Breadcrumb.vue";

    var useActive = (value) => ({
        activeClass: vue.computed(() => vue.unref(value) ? 'active' : undefined),
    });
    const activeProps = {
        active: {
            type: Boolean,
            default: false,
        },
    };

    var script$y = /*#__PURE__*/ vue.defineComponent({
        __name: 'BreadcrumbItem',
        props: Object.assign({}, activeProps),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                useActive(props.active).activeClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("li", {
                    class: vue.normalizeClass(["breadcrumb-item", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$y.__file = "src/components/BreadcrumbItem/BreadcrumbItem.vue";

    var useDisabled = (value) => ({
        disabledClass: vue.computed(() => vue.unref(value) ? 'disabled' : undefined),
    });
    const disabledProps = {
        disabled: {
            type: Boolean,
            default: false,
        },
    };

    const sizes = ['sm', 'md', 'lg', 'xl'];
    var useSize = (size, classTemplate) => {
        const { templatedString } = useStringTemplate(classTemplate, size);
        return { sizeClass: templatedString };
    };
    const sizeProps = {
        size: {
            type: String,
            default: 'md',
            validator: (v) => sizes.includes(v),
        },
    };

    const _hoisted_1$j = ["disabled"];
    var script$x = /*#__PURE__*/ vue.defineComponent({
        __name: 'Button',
        props: Object.assign(Object.assign(Object.assign(Object.assign({}, disabledProps), { outline: {
                type: Boolean,
                default: false,
            } }), sizeProps), variantProps),
        setup(__props) {
            const props = __props;
            const variantClassTemplate = vue.computed(() => `btn-${props.outline ? 'outline-' : ''}{0}`);
            const { classes } = useClasses(vue.computed(() => [
                useDisabled(props.disabled).disabledClass.value,
                useSize(props.size, 'btn-{0}').sizeClass.value,
                useVariant(props.variant, variantClassTemplate).variantClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("button", {
                    class: vue.normalizeClass(["btn", vue.unref(classes)]),
                    disabled: _ctx.disabled
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 10 /* CLASS, PROPS */, _hoisted_1$j));
            };
        }
    });

    script$x.__file = "src/components/Button/Button.vue";

    const _hoisted_1$i = ["disabled"];
    var script$w = /*#__PURE__*/ vue.defineComponent({
        __name: 'ButtonClose',
        props: Object.assign({}, disabledProps),
        setup(__props) {
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("button", {
                    class: "btn-close",
                    disabled: _ctx.disabled
                }, null, 8 /* PROPS */, _hoisted_1$i));
            };
        }
    });

    script$w.__file = "src/components/ButtonClose/ButtonClose.vue";

    var script$v = /*#__PURE__*/ vue.defineComponent({
        __name: 'ButtonGroup',
        props: Object.assign(Object.assign({}, sizeProps), { vertical: {
                type: Boolean,
                default: false,
            } }),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                vue.computed(() => props.vertical ? 'btn-group-vertical' : 'btn-group').value,
                useSize(props.size, 'btn-group-{0}').sizeClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(vue.unref(classes))
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$v.__file = "src/components/ButtonGroup/ButtonGroup.vue";

    const types$2 = ['border', 'grow'];
    var script$u = /*#__PURE__*/ vue.defineComponent({
        __name: 'Spinner',
        props: Object.assign(Object.assign(Object.assign({}, sizeProps), { type: {
                type: String,
                default: 'border',
                validator: (t) => types$2.includes(t),
            } }), variantProps),
        setup(__props) {
            const props = __props;
            const spinnerClass = useStringTemplate('spinner-{0}', vue.toRef(props, 'type')).templatedString;
            const { classes } = useClasses(vue.computed(() => [
                useSize(props.size, `${spinnerClass.value}-{0}`).sizeClass.value,
                spinnerClass.value,
                useVariant(props.variant, 'text-{0}').variantClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(vue.unref(classes))
                }, null, 2 /* CLASS */));
            };
        }
    });

    script$u.__file = "src/components/Spinner/Spinner.vue";

    const _hoisted_1$h = {
        key: 0,
        class: "me-2"
    };
    const _hoisted_2$d = {
        key: 1,
        class: "button-state-icon",
        "data-test": "success",
        fill: "currentColor",
        height: "1em",
        viewBox: "3 3 10 10",
        xmlns: "http://www.w3.org/2000/svg",
        width: "1em"
    };
    const _hoisted_3$7 = /*#__PURE__*/ vue.createElementVNode("path", { d: "M10.97 4.97a.75.75 0 0 1 1.07 1.05l-3.99 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.267.267 0 0 1 .02-.022z" }, null, -1 /* HOISTED */);
    const _hoisted_4$4 = [
        _hoisted_3$7
    ];
    const _hoisted_5$4 = {
        key: 2,
        class: "button-state-icon",
        "data-test": "error",
        fill: "currentColor",
        height: "1em",
        viewBox: "0 0 16 16",
        xmlns: "http://www.w3.org/2000/svg",
        width: "1em"
    };
    const _hoisted_6$3 = /*#__PURE__*/ vue.createElementVNode("path", { d: "M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z" }, null, -1 /* HOISTED */);
    const _hoisted_7$2 = /*#__PURE__*/ vue.createElementVNode("path", { d: "M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z" }, null, -1 /* HOISTED */);
    const _hoisted_8$1 = [
        _hoisted_6$3,
        _hoisted_7$2
    ];
    var script$t = /*#__PURE__*/ vue.defineComponent({
        __name: 'ButtonState',
        props: {
            error: {
                type: Boolean,
                default: false,
            },
            errorVariant: variantProp('danger'),
            loading: {
                type: Boolean,
                default: false,
            },
            success: {
                type: Boolean,
                default: false,
            },
            successVariant: variantProp('success'),
            variant: variantProp(),
        },
        setup(__props) {
            const props = __props;
            const disabled = vue.computed(() => props.loading);
            const variant = vue.computed(() => {
                switch (true) {
                    case props.success:
                        return props.successVariant;
                    case props.error:
                        return props.errorVariant;
                    default:
                        return props.variant;
                }
            });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.unref(script$x), {
                    disabled: vue.unref(disabled),
                    variant: vue.unref(variant)
                }, {
                    default: vue.withCtx(() => [
                        (__props.error || __props.loading || __props.success)
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$h, [
                                (__props.loading)
                                    ? (vue.openBlock(), vue.createBlock(vue.unref(script$u), {
                                        key: 0,
                                        size: "sm",
                                        variant: ""
                                    }))
                                    : vue.createCommentVNode("v-if", true),
                                (__props.success)
                                    ? (vue.openBlock(), vue.createElementBlock("svg", _hoisted_2$d, _hoisted_4$4))
                                    : vue.createCommentVNode("v-if", true),
                                (__props.error)
                                    ? (vue.openBlock(), vue.createElementBlock("svg", _hoisted_5$4, _hoisted_8$1))
                                    : vue.createCommentVNode("v-if", true)
                            ]))
                            : vue.createCommentVNode("v-if", true),
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["disabled", "variant"]));
            };
        }
    });

    script$t.__file = "src/components/ButtonState/ButtonState.vue";

    const _hoisted_1$g = { class: "card" };
    const _hoisted_2$c = {
        key: 0,
        class: "card-header"
    };
    const _hoisted_3$6 = {
        key: 0,
        class: "card-title"
    };
    const _hoisted_4$3 = {
        key: 1,
        class: "card-subtitle"
    };
    const _hoisted_5$3 = {
        key: 2,
        class: "card-text"
    };
    const _hoisted_6$2 = {
        key: 1,
        class: "card-footer"
    };
    var script$s = /*#__PURE__*/ vue.defineComponent({
        __name: 'Card',
        props: {
            footer: {
                type: String,
                default: undefined,
            },
            header: {
                type: String,
                default: undefined,
            },
            noBody: {
                type: Boolean,
                default: false,
            },
            subtitle: {
                type: String,
                default: undefined,
            },
            text: {
                type: String,
                default: undefined,
            },
            title: {
                type: String,
                default: undefined,
            },
        },
        setup(__props) {
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1$g, [
                    (!!_ctx.$slots.header || !!__props.header)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$c, [
                            vue.renderSlot(_ctx.$slots, "header", {}, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.header), 1 /* TEXT */)
                            ])
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass({ 'card-body': !__props.noBody })
                    }, [
                        vue.renderSlot(_ctx.$slots, "default", {}, () => [
                            (__props.title)
                                ? (vue.openBlock(), vue.createElementBlock("h5", _hoisted_3$6, vue.toDisplayString(__props.title), 1 /* TEXT */))
                                : vue.createCommentVNode("v-if", true),
                            (__props.subtitle)
                                ? (vue.openBlock(), vue.createElementBlock("h6", _hoisted_4$3, vue.toDisplayString(__props.subtitle), 1 /* TEXT */))
                                : vue.createCommentVNode("v-if", true),
                            (__props.text)
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_5$3, vue.toDisplayString(__props.text), 1 /* TEXT */))
                                : vue.createCommentVNode("v-if", true)
                        ])
                    ], 2 /* CLASS */),
                    (!!_ctx.$slots.footer || __props.footer)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_6$2, [
                            vue.renderSlot(_ctx.$slots, "footer", {}, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.footer), 1 /* TEXT */)
                            ])
                        ]))
                        : vue.createCommentVNode("v-if", true)
                ]));
            };
        }
    });

    script$s.__file = "src/components/Card/Card.vue";

    const _hoisted_1$f = ["id", "data-bs-interval"];
    const _hoisted_2$b = { class: "carousel-inner" };
    const _hoisted_3$5 = ["data-bs-interval"];
    const _hoisted_4$2 = ["src"];
    const _hoisted_5$2 = {
        key: 0,
        class: "carousel-caption d-none d-md-block"
    };
    const _hoisted_6$1 = { key: 0 };
    const _hoisted_7$1 = { key: 1 };
    const _hoisted_8 = { key: 0 };
    const _hoisted_9 = ["data-bs-target"];
    const _hoisted_10 = /*#__PURE__*/ vue.createElementVNode("span", { class: "carousel-control-prev-icon" }, null, -1 /* HOISTED */);
    const _hoisted_11 = [
        _hoisted_10
    ];
    const _hoisted_12 = ["data-bs-target"];
    const _hoisted_13 = /*#__PURE__*/ vue.createElementVNode("span", { class: "carousel-control-next-icon" }, null, -1 /* HOISTED */);
    const _hoisted_14 = [
        _hoisted_13
    ];
    const _hoisted_15 = {
        key: 1,
        class: "carousel-indicators"
    };
    const _hoisted_16 = ["data-bs-target", "data-bs-slide-to"];
    const carouselEvents = ['slid', 'slide'];
    var script$r = /*#__PURE__*/ vue.defineComponent({
        __name: 'Carousel',
        props: Object.assign(Object.assign({ dark: {
                type: Boolean,
                default: false,
            }, fade: {
                type: Boolean,
                default: false,
            }, hideControls: {
                type: Boolean,
                default: false,
            }, hideIndicators: {
                type: Boolean,
                default: false,
            } }, idProps), { interval: {
                type: Number,
                default: 5000,
            }, slides: {
                type: Array,
                default: () => [],
            } }),
        setup(__props, { expose, emit }) {
            const props = __props;
            const carousel = vue.ref();
            const activeIndex = vue.computed(() => {
                const activeSlideIndex = props.slides.findIndex((slide) => slide.active);
                return activeSlideIndex > -1 ? activeSlideIndex : 0;
            });
            useBootstrapEmits(carousel, carouselEvents, emit, 'carousel');
            const { bsInstance: bsCarousel } = useBootstrapInstance('Carousel', carousel);
            const { classes } = useClasses(vue.computed(() => [
                props.dark ? 'carousel-dark' : null,
                props.fade ? 'carousel-fade' : null,
            ]));
            expose({ bsCarousel });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    id: _ctx.id,
                    ref_key: "carousel",
                    ref: carousel,
                    class: vue.normalizeClass(["carousel slide", vue.unref(classes)]),
                    "data-bs-interval": __props.interval,
                    "data-bs-ride": "carousel"
                }, [
                    vue.createElementVNode("div", _hoisted_2$b, [
                        vue.renderSlot(_ctx.$slots, "slides", { slides: __props.slides }, () => [
                            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.slides, (slide, index) => {
                                return (vue.openBlock(), vue.createElementBlock("div", {
                                    key: `slide-${index}`,
                                    class: vue.normalizeClass(["carousel-item", { active: index === vue.unref(activeIndex) }]),
                                    "data-bs-interval": slide.interval
                                }, [
                                    vue.renderSlot(_ctx.$slots, "default", {
                                        index: index,
                                        slide: slide
                                    }, () => [
                                        (slide.image)
                                            ? (vue.openBlock(), vue.createElementBlock("img", {
                                                key: 0,
                                                src: slide.image,
                                                class: "d-block w-100"
                                            }, null, 8 /* PROPS */, _hoisted_4$2))
                                            : vue.createCommentVNode("v-if", true),
                                        vue.renderSlot(_ctx.$slots, "caption", {
                                            description: slide.description,
                                            title: slide.title
                                        }, () => [
                                            (slide.title || slide.description)
                                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_5$2, [
                                                    (slide.title)
                                                        ? (vue.openBlock(), vue.createElementBlock("h5", _hoisted_6$1, vue.toDisplayString(slide.title), 1 /* TEXT */))
                                                        : vue.createCommentVNode("v-if", true),
                                                    (slide.description)
                                                        ? (vue.openBlock(), vue.createElementBlock("p", _hoisted_7$1, vue.toDisplayString(slide.description), 1 /* TEXT */))
                                                        : vue.createCommentVNode("v-if", true)
                                                ]))
                                                : vue.createCommentVNode("v-if", true)
                                        ])
                                    ])
                                ], 10 /* CLASS, PROPS */, _hoisted_3$5));
                            }), 128 /* KEYED_FRAGMENT */))
                        ])
                    ]),
                    (!__props.hideControls)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_8, [
                            vue.createElementVNode("button", {
                                class: "carousel-control-prev",
                                "data-bs-target": `#${_ctx.id}`,
                                "data-bs-slide": "prev"
                            }, _hoisted_11, 8 /* PROPS */, _hoisted_9),
                            vue.createElementVNode("button", {
                                class: "carousel-control-next",
                                "data-bs-target": `#${_ctx.id}`,
                                "data-bs-slide": "next"
                            }, _hoisted_14, 8 /* PROPS */, _hoisted_12)
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    (!__props.hideIndicators)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_15, [
                            (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.slides, (_, index) => {
                                return (vue.openBlock(), vue.createElementBlock("button", {
                                    key: `slide-indicator-${index}`,
                                    class: vue.normalizeClass({ active: index === vue.unref(activeIndex) }),
                                    "data-bs-target": `#${_ctx.id}`,
                                    "data-bs-slide-to": index
                                }, null, 10 /* CLASS, PROPS */, _hoisted_16));
                            }), 128 /* KEYED_FRAGMENT */))
                        ]))
                        : vue.createCommentVNode("v-if", true)
                ], 10 /* CLASS, PROPS */, _hoisted_1$f));
            };
        }
    });

    script$r.__file = "src/components/Carousel/Carousel.vue";

    const breakpoints = ['sm', 'md', 'lg', 'xl', 'xxl'];
    var useBreakpoints = (props, classTemplate) => {
        const breakpointClasses = vue.computed(() => breakpoints
            .map(b => useStringTemplate(classTemplate, [b, vue.unref(props[b])]).templatedString.value));
        return {
            breakpointClasses: useClasses(breakpointClasses).classes,
        };
    };
    const breakpointProps = (propTemplate, template = '{0}') => {
        return Object.fromEntries(breakpoints.map((b) => [
            templateString(template, b),
            propTemplate,
        ]));
    };

    const colProp = {
        type: [Number, String],
        default: undefined,
        validator: (c) => c === 'auto' || c === '' || (c > 0 && c <= 12),
    };

    const propsCol$1 = breakpointProps(colProp);
    const propsOffset = breakpointProps(colProp, 'offset-{0}');
    const propsOrder = breakpointProps(colProp, 'order-{0}');
    var script$q = /*#__PURE__*/ vue.defineComponent({
        __name: 'Col',
        props: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({ cols: colProp }, propsCol$1), { offset: colProp }), propsOffset), { order: colProp }), propsOrder),
        setup(__props) {
            const props = __props;
            const colProps = {
                sm: vue.toRef(props, 'sm'),
                md: vue.toRef(props, 'md'),
                lg: vue.toRef(props, 'lg'),
                xl: vue.toRef(props, 'xl'),
                xxl: vue.toRef(props, 'xxl'),
            };
            const colClass = vue.computed(() => {
                // Add the `.col` class by default when no cols have been specified.
                if (props.cols) {
                    return useStringTemplate('col-{0}', props.cols).templatedString.value;
                }
                return 'col';
            });
            const colClasses = vue.computed(() => {
                // When the property is empty string it would result in for example
                // `col-md-`. These classes should be transformed to `col-md`.
                return useBreakpoints(colProps, 'col-{0}-{1}')
                    .breakpointClasses
                    .value
                    .map(c => c.replace(/\-$/, ''));
            });
            const offsetProps = {
                sm: vue.toRef(props, 'offsetSm'),
                md: vue.toRef(props, 'offsetMd'),
                lg: vue.toRef(props, 'offsetLg'),
                xl: vue.toRef(props, 'offsetXl'),
                xxl: vue.toRef(props, 'offsetXxl'),
            };
            const offsetClass = vue.computed(() => useStringTemplate('offset-{0}', props.offset).templatedString.value);
            const offsetClasses = useBreakpoints(offsetProps, 'offset-{0}-{1}').breakpointClasses;
            const orderProps = {
                sm: vue.toRef(props, 'orderSm'),
                md: vue.toRef(props, 'orderMd'),
                lg: vue.toRef(props, 'orderLg'),
                xl: vue.toRef(props, 'orderXl'),
                xxl: vue.toRef(props, 'orderXxl'),
            };
            const orderClass = vue.computed(() => useStringTemplate('order-{0}', props.order).templatedString.value);
            const orderClasses = useBreakpoints(orderProps, 'order-{0}-{1}').breakpointClasses;
            const { classes } = useClasses(vue.computed(() => [
                colClass.value,
                ...colClasses.value,
                offsetClass.value,
                ...offsetClasses.value,
                orderClass.value,
                ...orderClasses.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(vue.unref(classes))
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$q.__file = "src/components/Col/Col.vue";

    const _hoisted_1$e = ["data-bs-target"];
    const _hoisted_2$a = ["id", "data-bs-parent"];
    const collapseEvents = ['show', 'shown', 'hide', 'hidden'];
    var script$p = /*#__PURE__*/ vue.defineComponent({
        __name: 'Collapse',
        props: Object.assign(Object.assign({}, idProps), { 
            // Should be a valid query selector.
            parentSelector: {
                type: String,
                default: null,
            } }),
        setup(__props, { expose, emit }) {
            const collapse = vue.ref();
            useBootstrapEmits(collapse, collapseEvents, emit, 'collapse');
            const { bsInstance: bsCollapse } = useBootstrapInstance('Collapse', collapse, { toggle: false });
            expose({ bsCollapse });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock(vue.Fragment, null, [
                    vue.renderSlot(_ctx.$slots, "toggle", { id: _ctx.id }, () => [
                        vue.createElementVNode("div", vue.mergeProps({
                            class: "collapse-toggle",
                            "data-bs-toggle": "collapse",
                            "data-bs-target": `#${_ctx.id}`
                        }, _ctx.$attrs), [
                            vue.renderSlot(_ctx.$slots, "toggleContent", { id: _ctx.id })
                        ], 16 /* FULL_PROPS */, _hoisted_1$e)
                    ]),
                    vue.createElementVNode("div", {
                        id: _ctx.id,
                        ref_key: "collapse",
                        ref: collapse,
                        class: "collapse",
                        "data-bs-parent": __props.parentSelector
                    }, [
                        vue.renderSlot(_ctx.$slots, "default", { id: _ctx.id })
                    ], 8 /* PROPS */, _hoisted_2$a)
                ], 64 /* STABLE_FRAGMENT */));
            };
        }
    });

    script$p.__file = "src/components/Collapse/Collapse.vue";

    const _hoisted_1$d = ["id"];
    const _hoisted_2$9 = { class: "modal-content" };
    const _hoisted_3$4 = {
        key: 0,
        class: "modal-title"
    };
    const _hoisted_4$1 = {
        key: 1,
        class: "btn-close",
        "data-bs-dismiss": "modal",
        type: "button"
    };
    const _hoisted_5$1 = {
        key: 2,
        class: "modal-footer"
    };
    const modalEvents = ['show', 'shown', 'hide', 'hidden', 'hidePrevented'];
    var script$o = /*#__PURE__*/ vue.defineComponent({
        __name: 'Modal',
        props: Object.assign(Object.assign(Object.assign(Object.assign({ body: {
                type: String,
                default: undefined,
            }, headerClass: {
                type: [String, Array, Object],
                default: undefined,
            }, hideCloseBtn: {
                type: Boolean,
                default: false,
            } }, idProps), { modalCentered: {
                type: Boolean,
                default: false,
            }, noBody: {
                type: Boolean,
                default: false,
            } }), sizeProps), { title: {
                type: String,
                default: undefined,
            } }),
        setup(__props, { expose, emit }) {
            const props = __props;
            const modal = vue.ref();
            useBootstrapEmits(modal, modalEvents, emit, 'modal');
            const { bsInstance: bsModal } = useBootstrapInstance('Modal', modal);
            const { classes } = useClasses(vue.computed(() => [
                props.modalCentered ? 'modal-dialog-centered' : null,
                props.size ? useSize(props.size, 'modal-{0}').sizeClass.value : null,
            ]));
            vue.onBeforeUnmount(() => {
                if (bsModal.value) {
                    bsModal.value.hide();
                }
            });
            expose({ bsModal });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    id: _ctx.id,
                    ref_key: "modal",
                    ref: modal,
                    class: "modal"
                }, [
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass(["modal-dialog", vue.unref(classes)])
                    }, [
                        vue.createElementVNode("div", _hoisted_2$9, [
                            (!!_ctx.$slots.header || !!_ctx.$slots.title || !!__props.title || !__props.hideCloseBtn)
                                ? (vue.openBlock(), vue.createElementBlock("div", {
                                    key: 0,
                                    class: vue.normalizeClass(['modal-header', __props.headerClass])
                                }, [
                                    vue.renderSlot(_ctx.$slots, "header", {}, () => [
                                        (!!_ctx.$slots.title || !!__props.title)
                                            ? (vue.openBlock(), vue.createElementBlock("h5", _hoisted_3$4, [
                                                vue.renderSlot(_ctx.$slots, "title", {}, () => [
                                                    vue.createTextVNode(vue.toDisplayString(__props.title), 1 /* TEXT */)
                                                ])
                                            ]))
                                            : vue.createCommentVNode("v-if", true),
                                        (!__props.hideCloseBtn)
                                            ? (vue.openBlock(), vue.createElementBlock("button", _hoisted_4$1))
                                            : vue.createCommentVNode("v-if", true)
                                    ])
                                ], 2 /* CLASS */))
                                : vue.createCommentVNode("v-if", true),
                            (_ctx.$slots.default || __props.body)
                                ? (vue.openBlock(), vue.createElementBlock("div", {
                                    key: 1,
                                    class: vue.normalizeClass({ 'modal-body': !__props.noBody })
                                }, [
                                    vue.renderSlot(_ctx.$slots, "default", {}, () => [
                                        vue.createTextVNode(vue.toDisplayString(__props.body), 1 /* TEXT */)
                                    ])
                                ], 2 /* CLASS */))
                                : vue.createCommentVNode("v-if", true),
                            (_ctx.$slots.footer)
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_5$1, [
                                    vue.renderSlot(_ctx.$slots, "footer")
                                ]))
                                : vue.createCommentVNode("v-if", true)
                        ])
                    ], 2 /* CLASS */)
                ], 8 /* PROPS */, _hoisted_1$d));
            };
        }
    });

    script$o.__file = "src/components/Modal/Modal.vue";

    var script$n = /*#__PURE__*/ vue.defineComponent({
        __name: 'Confirm',
        props: {
            body: {
                type: String,
                default: 'Are you sure?',
            },
            cancelOutline: {
                type: Boolean,
                default: false,
            },
            cancelText: {
                type: String,
                default: 'No',
            },
            cancelVariant: variantProp('light'),
            okText: {
                type: String,
                default: 'Yes',
            },
            okVariant: variantProp('primary'),
            title: {
                type: String,
                default: 'Confirmation',
            },
        },
        emits: ["cancelled", "confirmed"],
        setup(__props, { expose, emit }) {
            const cancel = () => {
                emit('cancelled');
                hide();
            };
            const ok = () => {
                emit('confirmed');
                hide();
            };
            const modal = vue.ref();
            const hide = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.hide(); };
            const show = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.show(); };
            const toggle = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.toggle(); };
            expose({ hide, show, toggle });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.unref(script$o), {
                    ref_key: "modal",
                    ref: modal,
                    title: __props.title
                }, {
                    footer: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "buttonCancel", {}, () => [
                            vue.createVNode(vue.unref(script$x), {
                                class: "button-cancel",
                                outline: __props.cancelOutline,
                                variant: __props.cancelVariant,
                                onClick: cancel
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createTextVNode(vue.toDisplayString(__props.cancelText), 1 /* TEXT */)
                                ]),
                                _: 1 /* STABLE */
                            }, 8 /* PROPS */, ["outline", "variant"])
                        ]),
                        vue.renderSlot(_ctx.$slots, "buttonOk", {}, () => [
                            vue.createVNode(vue.unref(script$x), {
                                class: "button-ok",
                                variant: __props.okVariant,
                                onClick: ok
                            }, {
                                default: vue.withCtx(() => [
                                    vue.createTextVNode(vue.toDisplayString(__props.okText), 1 /* TEXT */)
                                ]),
                                _: 1 /* STABLE */
                            }, 8 /* PROPS */, ["variant"])
                        ])
                    ]),
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default", {}, () => [
                            vue.createTextVNode(vue.toDisplayString(__props.body), 1 /* TEXT */)
                        ])
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["title"]));
            };
        }
    });

    script$n.__file = "src/components/Confirm/Confirm.vue";

    var script$m = /*#__PURE__*/ vue.defineComponent({
        __name: 'Container',
        props: {
            fluid: {
                type: Boolean,
                default: false,
            },
        },
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                `container${props.fluid ? '-fluid' : ''}`,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(vue.unref(classes))
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$m.__file = "src/components/Container/Container.vue";

    const dropdownItemsProps = {
        items: {
            type: Array,
            default: () => [],
        },
    };

    const _hoisted_1$c = {
        key: 0,
        class: "dropdown-divider"
    };
    const _hoisted_2$8 = {
        key: 1,
        class: "dropdown-header"
    };
    var script$l = /*#__PURE__*/ vue.defineComponent({
        __name: 'DropdownMenuItem',
        props: {
            active: {
                type: Boolean,
                default: false,
            },
            divider: {
                type: Boolean,
                default: false,
            },
            header: {
                type: Boolean,
                default: false,
            },
            label: {
                type: String,
                default: undefined,
            },
        },
        setup(__props) {
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("li", null, [
                    (__props.divider)
                        ? (vue.openBlock(), vue.createElementBlock("hr", _hoisted_1$c))
                        : (__props.header)
                            ? (vue.openBlock(), vue.createElementBlock("h6", _hoisted_2$8, vue.toDisplayString(__props.label), 1 /* TEXT */))
                            : (vue.openBlock(), vue.createElementBlock("a", {
                                key: 2,
                                class: vue.normalizeClass(["dropdown-item", { active: __props.active }]),
                                href: "#",
                                onClick: _cache[0] || (_cache[0] = vue.withModifiers(() => { }, ["prevent"]))
                            }, vue.toDisplayString(__props.label), 3 /* TEXT, CLASS */))
                ]));
            };
        }
    });

    script$l.__file = "src/components/DropdownMenuItem/DropdownMenuItem.vue";

    const _hoisted_1$b = { class: "dropdown-menu" };
    var script$k = /*#__PURE__*/ vue.defineComponent({
        __name: 'DropdownMenu',
        props: dropdownItemsProps,
        emits: ['click:item'],
        setup(__props, { emit }) {
            const clickItem = (item) => emit('click:item', item);
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("ul", _hoisted_1$b, [
                    vue.renderSlot(_ctx.$slots, "prepend"),
                    vue.renderSlot(_ctx.$slots, "items", {
                        clickItem: clickItem,
                        items: _ctx.items
                    }, () => [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.items, (item, index) => {
                            return vue.renderSlot(_ctx.$slots, "item", {
                                key: `item-${index.toString()}`,
                                clickItem: clickItem,
                                item: item
                            }, () => [
                                vue.createVNode(vue.unref(script$l), vue.mergeProps(item, {
                                    onClick: ($event) => (clickItem(item))
                                }), null, 16 /* FULL_PROPS */, ["onClick"])
                            ]);
                        }), 128 /* KEYED_FRAGMENT */))
                    ]),
                    vue.renderSlot(_ctx.$slots, "append")
                ]));
            };
        }
    });

    script$k.__file = "src/components/DropdownMenu/DropdownMenu.vue";

    const dropdownProps = Object.assign(Object.assign(Object.assign(Object.assign({}, dropdownItemsProps), { menuClass: {
            type: String,
            default: undefined,
        } }), sizeProps), variantProps);

    const _hoisted_1$a = /*#__PURE__*/ vue.createTextVNode(" Select ");
    const dropdownEvents = ['show', 'shown', 'hide', 'hidden'];
    var script$j = /*#__PURE__*/ vue.defineComponent({
        __name: 'Dropdown',
        props: dropdownProps,
        setup(__props, { expose, emit }) {
            const dropdown = vue.ref();
            useBootstrapEmits(dropdown, dropdownEvents, emit, 'dropdown');
            const { bsInstance: bsDropdown } = useBootstrapInstance('Dropdown', dropdown);
            expose({ bsDropdown });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    ref_key: "dropdown",
                    ref: dropdown,
                    class: "dropdown"
                }, [
                    vue.renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
                        vue.createVNode(vue.unref(script$x), {
                            class: "dropdown-toggle",
                            "data-bs-toggle": "dropdown",
                            size: _ctx.size,
                            variant: _ctx.variant
                        }, {
                            default: vue.withCtx(() => [
                                vue.renderSlot(_ctx.$slots, "default", {}, () => [
                                    _hoisted_1$a
                                ])
                            ]),
                            _: 3 /* FORWARDED */
                        }, 8 /* PROPS */, ["size", "variant"])
                    ]),
                    vue.renderSlot(_ctx.$slots, "dropdownMenu", vue.mergeProps({ 'onClick:item': _ctx.$attrs['onClick:item'] }, { items: _ctx.items }), () => [
                        vue.createVNode(vue.unref(script$k), vue.mergeProps({
                            items: _ctx.items,
                            class: _ctx.menuClass
                        }, { 'onClick:item': _ctx.$attrs['onClick:item'] }), {
                            prepend: vue.withCtx((slotScope) => [
                                vue.renderSlot(_ctx.$slots, "prepend", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                            ]),
                            items: vue.withCtx((slotScope) => [
                                vue.renderSlot(_ctx.$slots, "items", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                            ]),
                            item: vue.withCtx((slotScope) => [
                                vue.renderSlot(_ctx.$slots, "item", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                            ]),
                            append: vue.withCtx((slotScope) => [
                                vue.renderSlot(_ctx.$slots, "append", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                            ]),
                            _: 3 /* FORWARDED */
                        }, 16 /* FULL_PROPS */, ["items", "class"])
                    ])
                ], 512 /* NEED_PATCH */));
            };
        }
    });

    script$j.__file = "src/components/Dropdown/Dropdown.vue";

    const types$1 = ['checkbox', 'radio'];
    const typeProp = {
        type: String,
        default: 'checkbox',
        validator: (t) => types$1.includes(t),
    };

    const _hoisted_1$9 = ["id", "disabled", "name", "type", "value"];
    const _hoisted_2$7 = ["for"];
    var script$i = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormCheck',
        props: Object.assign(Object.assign(Object.assign({}, disabledProps), idProps), { inline: {
                type: Boolean,
                default: false,
            }, inputClass: {
                type: [String, Array, Object],
                default: undefined,
            }, label: {
                type: String,
                default: undefined,
            }, modelValue: {
                type: [Boolean, String, Number],
                default: false,
            }, name: {
                type: String,
                default: undefined,
            }, switch: {
                type: Boolean,
                default: false,
            }, type: typeProp, value: {
                type: [String, Number],
                default: undefined,
            } }),
        emits: ['update:modelValue'],
        setup(__props, { emit }) {
            const props = __props;
            const checked = vue.computed({
                get: () => props.modelValue,
                set(v) {
                    let value = v;
                    if (props.value) {
                        value = v ? props.value : undefined;
                    }
                    emit('update:modelValue', value);
                },
            });
            // Required to prevent the use of a reserved word.
            const isSwitch = vue.computed(() => props.switch);
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(["form-check", { 'form-switch': vue.unref(isSwitch), 'form-check-inline': __props.inline }])
                }, [
                    vue.withDirectives(vue.createElementVNode("input", {
                        id: _ctx.id,
                        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => (vue.isRef(checked) ? (checked).value = $event : null)),
                        class: vue.normalizeClass(["form-check-input", __props.inputClass]),
                        disabled: _ctx.disabled,
                        name: __props.name,
                        type: __props.type,
                        value: __props.value
                    }, null, 10 /* CLASS, PROPS */, _hoisted_1$9), [
                        [vue.vModelDynamic, vue.unref(checked)]
                    ]),
                    (_ctx.$slots.default || __props.label)
                        ? (vue.openBlock(), vue.createElementBlock("label", {
                            key: 0,
                            class: "form-check-label",
                            for: _ctx.id
                        }, [
                            vue.renderSlot(_ctx.$slots, "default", {}, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                            ])
                        ], 8 /* PROPS */, _hoisted_2$7))
                        : vue.createCommentVNode("v-if", true)
                ], 2 /* CLASS */));
            };
        }
    });

    script$i.__file = "src/components/FormCheck/FormCheck.vue";

    var script$h = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormCheckGroup',
        props: Object.assign(Object.assign({}, disabledProps), { switch: {
                type: Boolean,
                default: false,
            }, items: {
                type: Array,
                required: true,
            }, type: typeProp, 
            // Put `modelValue` after `type` so it will be available in `default`.
            modelValue: {
                type: [Array, String, Number, undefined],
                default: (props) => props.type === 'checkbox' ? [] : undefined,
            } }),
        emits: ['update:modelValue'],
        setup(__props, { emit }) {
            const props = __props;
            const name = props.type === 'checkbox' ? undefined : idProps.id.default();
            // Required to prevent the use of reserved word `switch` in template.
            const isSwitch = vue.computed(() => props.switch);
            const value = vue.computed({
                get: () => props.modelValue,
                set: (v) => emit('update:modelValue', v),
            });
            const getValue = (i) => props.type === 'checkbox' ? !!value.value[i] : value.value;
            const setValue = (v, i) => {
                if (props.type === 'checkbox') {
                    const clone = [...value.value];
                    clone[i] = v;
                    value.value = clone;
                }
                else {
                    value.value = v;
                }
            };
            return (_ctx, _cache) => {
                return (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.items, (item, index) => {
                    return (vue.openBlock(), vue.createBlock(vue.unref(script$i), {
                        key: item.value,
                        disabled: _ctx.disabled,
                        label: item.label || item.value,
                        "model-value": getValue(index),
                        name: vue.unref(name),
                        type: __props.type,
                        switch: vue.unref(isSwitch),
                        value: item.value,
                        "onUpdate:modelValue": ($event) => (setValue($event, index))
                    }, null, 8 /* PROPS */, ["disabled", "label", "model-value", "name", "type", "switch", "value", "onUpdate:modelValue"]));
                }), 128 /* KEYED_FRAGMENT */));
            };
        }
    });

    script$h.__file = "src/components/FormCheckGroup/FormCheckGroup.vue";

    const types = ['date', 'email', 'number', 'password', 'text'];
    const formControlProps = Object.assign(Object.assign(Object.assign(Object.assign({ autofocus: {
            type: Boolean,
            default: false,
        } }, disabledProps), { modelValue: {
            type: String,
            default: '',
        }, placeholder: {
            type: String,
            default: '',
        }, plainText: {
            type: Boolean,
            default: false,
        }, readonly: {
            type: Boolean,
            default: false,
        } }), sizeProps), { type: {
            type: String,
            default: 'text',
            validator: (v) => types.includes(v),
        } });

    const _hoisted_1$8 = ["autofocus", "disabled", "placeholder", "readonly", "type", "value"];
    var script$g = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormControl',
        props: formControlProps,
        emits: ['update:modelValue'],
        setup(__props, { expose, emit }) {
            const props = __props;
            const input = vue.ref();
            const { classes } = useClasses(vue.computed(() => [
                useDisabled(props.disabled).disabledClass.value,
                props.plainText ? 'form-control-plaintext' : '',
                props.readonly ? 'readonly' : '',
                useSize(props.size, 'form-control-{0}').sizeClass.value,
            ]));
            expose({ input });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("input", {
                    ref_key: "input",
                    ref: input,
                    autofocus: _ctx.autofocus,
                    class: vue.normalizeClass(["form-control", vue.unref(classes)]),
                    disabled: _ctx.disabled,
                    placeholder: _ctx.placeholder,
                    readonly: _ctx.readonly,
                    type: _ctx.type,
                    value: _ctx.modelValue,
                    onInput: _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event.target.value)))
                }, null, 42 /* CLASS, PROPS, HYDRATE_EVENTS */, _hoisted_1$8));
            };
        }
    });

    script$g.__file = "src/components/FormControl/FormControl.vue";

    var useFormSelect = (props) => useClasses(vue.computed(() => [
        useDisabled(vue.unref(props).disabled).disabledClass.value,
        useSize(vue.unref(props).size, 'form-select-{0}').sizeClass.value,
    ]));
    const formSelectProps = Object.assign(Object.assign(Object.assign({}, disabledProps), { items: {
            type: Array,
            default: () => [],
        } }), sizeProps);

    var extractKeysFrom = (keys, from) => vue.computed(() => Object.fromEntries(keys.map(k => [k, from[k]])));

    const { disabled: disabledProp, size: sizeProp } = formSelectProps;
    var script$f = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormDropdown',
        props: Object.assign(Object.assign({}, dropdownProps), { disabled: disabledProp, labelKey: {
                type: String,
                default: 'label',
            }, menuClass: {
                type: String,
                default: 'w-100',
            }, modelValue: {
                type: Object,
                default: undefined,
            }, placeholder: {
                type: String,
                default: 'Select',
            }, size: sizeProp, toggleClass: {
                type: String,
                default: undefined,
            } }),
        emits: ['update:modelValue'],
        setup(__props, { emit }) {
            const props = __props;
            const propsDropdown = extractKeysFrom(Object.keys(dropdownProps), props);
            const label = vue.computed(() => {
                if (!props.modelValue) {
                    return props.placeholder;
                }
                return props.modelValue[props.labelKey];
            });
            const { classes } = useClasses(vue.computed(() => [
                ...useFormSelect(props).classes.value,
                props.toggleClass,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.unref(script$j), vue.mergeProps({ class: "form-dropdown" }, vue.unref(propsDropdown), {
                    "onClick:item": _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event)))
                }), {
                    dropdownToggle: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
                            vue.createElementVNode("div", {
                                class: vue.normalizeClass(["form-select", vue.unref(classes)]),
                                "data-bs-toggle": "dropdown"
                            }, vue.toDisplayString(vue.unref(label)), 3 /* TEXT, CLASS */)
                        ])
                    ]),
                    prepend: vue.withCtx(() => [
                        (_ctx.items.length === 0)
                            ? vue.renderSlot(_ctx.$slots, "noOptions", { key: 0 }, () => [
                                vue.createVNode(vue.unref(script$l), {
                                    class: "pe-none",
                                    label: "No options"
                                })
                            ])
                            : vue.createCommentVNode("v-if", true),
                        vue.renderSlot(_ctx.$slots, "prepend")
                    ]),
                    items: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "items", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    item: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "item", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    append: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "append", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    _: 3 /* FORWARDED */
                }, 16 /* FULL_PROPS */));
            };
        }
    });

    script$f.__file = "src/components/FormDropdown/FormDropdown.vue";

    var script$e = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormDropdownSearch',
        props: Object.assign(Object.assign({}, formControlProps), { autoSearch: {
                type: Boolean,
                default: true,
            }, items: {
                type: Array,
                default: () => [],
            }, labelKey: {
                type: String,
                default: 'label',
            }, modelValue: {
                type: Object,
                default: undefined,
            }, placeholder: {
                type: String,
                default: '',
            }, search: {
                type: String,
                default: '',
            } }),
        emits: ['update:modelValue', 'update:search'],
        setup(__props, { expose, emit }) {
            const props = __props;
            const propsFormControl = extractKeysFrom(Object.keys(formControlProps)
                .filter(k => !['modelValue', 'placeholder'].includes(k)), props);
            const propsDropdown = extractKeysFrom(Object.keys(dropdownProps)
                .filter(k => !['items', 'labelKey'].includes(k)), props);
            const filteredItems = vue.computed(() => {
                if (searchValue.value === '' || !props.autoSearch) {
                    return props.items;
                }
                return props.items
                    .filter(i => i.label
                    .toLowerCase()
                    .includes(searchValue.value.toLocaleLowerCase()));
            });
            const formControl = vue.ref();
            const formDropdown = vue.ref();
            const { bsInstance: bsDropdown } = useBootstrapInstance('Dropdown', formControl);
            const modelValue = vue.computed({
                get: () => props.modelValue,
                set: v => emit('update:modelValue', v),
            });
            const modelValueLabel = vue.computed(() => { var _a; return (_a = modelValue.value) === null || _a === void 0 ? void 0 : _a[props.labelKey]; });
            const searchValue = vue.ref(modelValueLabel.value || props.search);
            /**
             * Is used to display a temporary value in the input while still emitting an
             * empty `search` to the parent. This will for example happen when this
             * component has a `modelValue` and the user focuses on the input. The parent
             * should receive an empty `search` so it can display more options than options
             * that match the `labelKey` of the `modelValue`. It acts af is there is no
             * `search` while still displaying the `modelValue`.
             */
            const searchValueCached = vue.ref('');
            const searchValueDisplayed = vue.computed({
                get: () => {
                    return searchValueCached.value !== ''
                        ? ''
                        : searchValue.value;
                },
                set: s => {
                    searchValue.value = s;
                    emit('update:search', s);
                },
            });
            vue.onMounted(() => {
                // Get the dropdown toggle element manually because it is possible to
                // override it with the `dropdownToggle` slot.
                const dropdownToggle = formDropdown.value
                    .$el
                    .querySelector('[data-bs-toggle="dropdown"]');
                dropdownToggle === null || dropdownToggle === void 0 ? void 0 : dropdownToggle.addEventListener('shown.bs.dropdown', () => {
                    var _a;
                    (_a = dropdownToggle.input) === null || _a === void 0 ? void 0 : _a.focus();
                    if (modelValueLabel.value) {
                        searchValueCached.value = modelValueLabel.value;
                    }
                    searchValue.value = '';
                    if (props.search !== '') {
                        emit('update:search', '');
                    }
                });
                dropdownToggle === null || dropdownToggle === void 0 ? void 0 : dropdownToggle.addEventListener('hidden.bs.dropdown', () => {
                    var _a;
                    (_a = dropdownToggle.input) === null || _a === void 0 ? void 0 : _a.blur();
                    if (!modelValue.value) {
                        searchValue.value = '';
                    }
                    else {
                        searchValue.value = modelValueLabel.value;
                    }
                    searchValueCached.value = '';
                });
            });
            const showMenu = () => {
                if (bsDropdown.value) {
                    // TODO: BS calls `toggle` once a user clicks on any
                    // `data-bs-toggle="dropdown"`. This event is being fired after the
                    // `focus` event, thus will result in hiding the menu after we call
                    // `show`. `await nextTick()` also does not solve this problem.
                    setTimeout(() => bsDropdown.value.show(), 200);
                }
            };
            vue.watch(modelValue, newValue => {
                if (newValue) {
                    searchValue.value = newValue[props.labelKey];
                }
                else {
                    searchValue.value = '';
                }
            });
            vue.watch(() => props.search, s => searchValue.value = s);
            expose({ bsDropdown, formControl });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.unref(script$f), vue.mergeProps({
                    ref_key: "formDropdown",
                    ref: formDropdown,
                    modelValue: vue.unref(modelValue),
                    "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => (vue.isRef(modelValue) ? (modelValue).value = $event : null)),
                    items: vue.unref(filteredItems),
                    "label-key": __props.labelKey
                }, vue.unref(propsDropdown)), {
                    dropdownToggle: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
                            vue.createVNode(vue.unref(script$g), vue.mergeProps({
                                ref_key: "formControl",
                                ref: formControl,
                                modelValue: vue.unref(searchValueDisplayed),
                                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => (vue.isRef(searchValueDisplayed) ? (searchValueDisplayed).value = $event : null)),
                                class: "form-select",
                                "data-bs-toggle": "dropdown",
                                placeholder: searchValueCached.value || __props.placeholder
                            }, vue.unref(propsFormControl), { onFocus: showMenu }), null, 16 /* FULL_PROPS */, ["modelValue", "placeholder"])
                        ])
                    ]),
                    noOptions: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "noOptions", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    prepend: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "prepend", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    items: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "items", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    item: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "item", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    append: vue.withCtx((slotScope) => [
                        vue.renderSlot(_ctx.$slots, "append", vue.normalizeProps(vue.guardReactiveProps(slotScope)))
                    ]),
                    _: 3 /* FORWARDED */
                }, 16 /* FULL_PROPS */, ["modelValue", "items", "label-key"]));
            };
        }
    });

    script$e.__file = "src/components/FormDropdownSearch/FormDropdownSearch.vue";

    const _hoisted_1$7 = ["for"];
    const _hoisted_2$6 = {
        key: 0,
        class: "form-text"
    };
    const _hoisted_3$3 = {
        key: 3,
        class: "form-text"
    };
    var script$d = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormGroup',
        props: Object.assign(Object.assign(Object.assign({ description: {
                type: String,
                default: undefined,
            }, helpText: {
                type: String,
                default: undefined,
            } }, idProps), formControlProps), { invalidFeedback: {
                type: [Array, String],
                default: () => [],
            }, label: {
                type: String,
                default: undefined,
            }, labelClass: {
                type: [String, Array, Object],
                default: undefined,
            }, validFeedback: {
                type: [Array, String],
                default: () => [],
            } }),
        emits: ['update:modelValue'],
        setup(__props, { emit }) {
            const props = __props;
            const propsFormControl = extractKeysFrom(Object.keys(formControlProps), props);
            const invalidFeedback = vue.computed(() => [props.invalidFeedback].flat().filter(f => !!f));
            const isInvalid = vue.computed(() => !!invalidFeedback.value.length);
            const validFeedback = vue.computed(() => [props.validFeedback].flat().filter(f => !!f));
            const isValid = vue.computed(() => !!validFeedback.value.length);
            const validityClass = vue.computed(() => [
                isInvalid.value ? 'is-invalid' : undefined,
                isValid.value ? 'is-valid' : undefined,
            ]);
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", null, [
                    (!!_ctx.$slots.label || __props.label || __props.description)
                        ? (vue.openBlock(), vue.createElementBlock("label", {
                            key: 0,
                            class: vue.normalizeClass(["form-label", __props.labelClass]),
                            for: _ctx.id
                        }, [
                            vue.renderSlot(_ctx.$slots, "label", { label: __props.label }, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.label), 1 /* TEXT */)
                            ]),
                            (!!__props.description)
                                ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$6, vue.toDisplayString(__props.description), 1 /* TEXT */))
                                : vue.createCommentVNode("v-if", true)
                        ], 10 /* CLASS, PROPS */, _hoisted_1$7))
                        : vue.createCommentVNode("v-if", true),
                    vue.renderSlot(_ctx.$slots, "default", {
                        isInvalid: vue.unref(isInvalid),
                        isValid: vue.unref(isValid)
                    }, () => [
                        vue.createVNode(vue.unref(script$g), vue.mergeProps(vue.unref(propsFormControl), {
                            id: _ctx.id,
                            class: vue.unref(validityClass),
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event)))
                        }), null, 16 /* FULL_PROPS */, ["id", "class"])
                    ]),
                    (vue.unref(isInvalid))
                        ? (vue.openBlock(true), vue.createElementBlock(vue.Fragment, { key: 1 }, vue.renderList(vue.unref(invalidFeedback), (feedback) => {
                            return (vue.openBlock(), vue.createElementBlock("div", {
                                key: feedback,
                                class: "invalid-feedback"
                            }, vue.toDisplayString(feedback), 1 /* TEXT */));
                        }), 128 /* KEYED_FRAGMENT */))
                        : vue.createCommentVNode("v-if", true),
                    (vue.unref(isValid))
                        ? (vue.openBlock(true), vue.createElementBlock(vue.Fragment, { key: 2 }, vue.renderList(vue.unref(validFeedback), (feedback) => {
                            return (vue.openBlock(), vue.createElementBlock("div", {
                                key: feedback,
                                class: "valid-feedback"
                            }, vue.toDisplayString(feedback), 1 /* TEXT */));
                        }), 128 /* KEYED_FRAGMENT */))
                        : vue.createCommentVNode("v-if", true),
                    (__props.helpText)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3$3, vue.toDisplayString(__props.helpText), 1 /* TEXT */))
                        : vue.createCommentVNode("v-if", true)
                ]));
            };
        }
    });

    script$d.__file = "src/components/FormGroup/FormGroup.vue";

    const _hoisted_1$6 = ["for"];
    const _hoisted_2$5 = ["id"];
    const _hoisted_3$2 = {
        key: 0,
        class: "form-image-btn-edit"
    };
    var script$c = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormImage',
        props: Object.assign(Object.assign({ dataType: {
                type: String,
                default: 'base64',
            } }, idProps), { modelValue: {
                type: [Object, String],
                default: undefined,
            }, preview: {
                type: String,
                default: undefined,
            } }),
        emits: ["update:modelValue"],
        setup(__props, { emit }) {
            const props = __props;
            // Rollup cannot handle HTMLInputElement as ref, cannot
            const input = vue.ref();
            const preview = vue.ref(props.preview);
            const file = vue.ref();
            const style = vue.computed(() => {
                if (!preview.value) {
                    return {};
                }
                return {
                    'background-color': 'transparent',
                    'background-image': `url(${preview.value})`,
                    'background-size': 'cover',
                };
            });
            const value = vue.computed({
                get: () => props.modelValue,
                set: (v) => emit('update:modelValue', v),
            });
            vue.watch(file, f => readFile(f));
            const onChange = (e) => {
                const newFile = e.target.files.item(0);
                if (newFile === null || newFile === void 0 ? void 0 : newFile.type.match('image.*')) {
                    file.value = newFile;
                    return true;
                }
                return false;
            };
            const onDrop = (e) => {
                e.preventDefault();
                input.value.files = e.dataTransfer.files;
                onChange({ target: input.value });
            };
            const readFile = (file) => {
                if (!file) {
                    return value.value = undefined;
                }
                if (props.dataType === 'file') {
                    value.value = file;
                }
                const reader = new FileReader();
                reader.onload = () => {
                    preview.value = reader.result;
                    if (props.dataType === 'base64') {
                        value.value = reader.result;
                    }
                };
                reader.readAsDataURL(file);
                return reader;
            };
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("label", {
                    class: vue.normalizeClass(["form-image", { 'form-image-has-preview': !!preview.value }]),
                    for: _ctx.id,
                    style: vue.normalizeStyle(vue.unref(style)),
                    onDrop: onDrop,
                    onDragenter: _cache[0] || (_cache[0] = vue.withModifiers(() => { }, ["prevent"])),
                    onDragover: _cache[1] || (_cache[1] = vue.withModifiers(() => { }, ["prevent"]))
                }, [
                    vue.createElementVNode("input", {
                        id: _ctx.id,
                        ref_key: "input",
                        ref: input,
                        accept: "image/*",
                        hidden: "",
                        type: "file",
                        onChange: onChange
                    }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_2$5),
                    (preview.value)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_3$2))
                        : vue.renderSlot(_ctx.$slots, "placeholder", { key: 1 })
                ], 46 /* CLASS, STYLE, PROPS, HYDRATE_EVENTS */, _hoisted_1$6));
            };
        }
    });

    script$c.__file = "src/components/FormImage/FormImage.vue";

    const _hoisted_1$5 = ["for"];
    const _hoisted_2$4 = { class: "list-unstyled d-flex align-content-start flex-wrap mb-0" };
    const _hoisted_3$1 = { class: "form-pill-text" };
    const _hoisted_4 = ["onClick"];
    const _hoisted_5 = { class: "form-pill-input-item" };
    const _hoisted_6 = { class: "form-pill-input-sizer overflow-hidden" };
    const _hoisted_7 = ["id", "placeholder"];
    var script$b = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormPills',
        props: Object.assign(Object.assign({ editItemOnBackspace: {
                type: Boolean,
                default: false,
            } }, idProps), { maxItems: {
                type: Number,
                default: Infinity,
            }, modelValue: {
                type: Array,
                default: () => [],
            }, placeholder: {
                type: String,
                default: '',
            }, separator: {
                type: [String, RegExp],
                // For some reason it does not allow RegExp to be used as default value.
                // eslint-disable-next-line vue/require-valid-default-prop
                default: /[\s\n]+/,
            }, submitKeys: {
                type: Array,
                default: () => ['Enter'],
            }, valueMatcher: {
                type: [String, RegExp],
                // For some reason it does not allow RegExp to be used as default value.
                // eslint-disable-next-line vue/require-valid-default-prop
                default: /^.+$/,
            } }),
        emits: ['update:modelValue'],
        setup(__props, { emit }) {
            const props = __props;
            const value = vue.ref('');
            const clearValue = () => value.value = '';
            const items = vue.computed({
                get: () => props.modelValue,
                set: (v) => emit('update:modelValue', v),
            });
            const maxItemsReached = vue.computed(() => items.value.length >= props.maxItems);
            const matchItem = (item) => !!item.match(props.valueMatcher);
            const splitItem = (item) => item.split(props.separator);
            const removeItem = (index) => items.value.splice(index, 1);
            const validateValue = (value) => {
                if (Array.isArray(value)) {
                    return value.every(validateValue);
                }
                return matchItem(value);
            };
            const addItem = (item) => {
                if (maxItemsReached.value) {
                    return false;
                }
                const newItems = splitItem(item).filter(matchItem);
                if (newItems.length === 0) {
                    return false;
                }
                const allowedItems = newItems.slice(0, props.maxItems - items.value.length);
                items.value = items.value.concat(allowedItems);
                return true;
            };
            vue.watch(value, (v) => {
                const splitItems = splitItem(v);
                if (splitItems.length > 1
                    && splitItems.filter(validateValue).length === splitItems.filter(v => v !== '').length) {
                    addItem(v);
                    clearValue();
                }
            });
            // We need to pass the Focus Event to the blur method in order for the test to
            // be able to mock the blur method.
            const blur = (event) => {
                const splitItems = splitItem(value.value);
                if (validateValue(splitItems)) {
                    addItem(value.value);
                    clearValue();
                }
            };
            const keydown = (event) => {
                if (event.code === 'Backspace') {
                    if (value.value !== '') {
                        return;
                    }
                    const [removedItem] = removeItem(items.value.length - 1);
                    if (props.editItemOnBackspace && removedItem) {
                        value.value = removedItem;
                        event.preventDefault();
                    }
                    return;
                }
                // If the max allowed items has been reached, don't allow any more typing.
                if (maxItemsReached.value) {
                    event.preventDefault();
                    return;
                }
                if (props.submitKeys.includes(event.code)) {
                    const splitItems = splitItem(value.value);
                    if (validateValue(splitItems)) {
                        addItem(value.value);
                        clearValue();
                    }
                    event.preventDefault();
                }
            };
            const paste = (event) => {
                event.preventDefault();
                const pasteValue = event.clipboardData.getData('text');
                if (!pasteValue) {
                    return;
                }
                const newValue = value.value + pasteValue;
                const splitItems = splitItem(newValue);
                // If the input value together with the paste value are valid, add the items,
                // otherwise concat the paste value to the input value.
                if (validateValue(splitItems)) {
                    addItem(newValue);
                    clearValue();
                }
                else {
                    value.value = newValue;
                }
            };
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("label", {
                    class: "form-control",
                    for: _ctx.id
                }, [
                    vue.createElementVNode("ul", _hoisted_2$4, [
                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(__props.modelValue, (item, i) => {
                            return (vue.openBlock(), vue.createElementBlock("li", {
                                key: i,
                                class: "form-pill d-inline-flex align-items-center mw-100"
                            }, [
                                vue.createElementVNode("div", _hoisted_3$1, vue.toDisplayString(item), 1 /* TEXT */),
                                vue.createElementVNode("div", {
                                    class: "form-pill-remove",
                                    onClick: ($event) => (removeItem(i))
                                }, null, 8 /* PROPS */, _hoisted_4)
                            ]));
                        }), 128 /* KEYED_FRAGMENT */)),
                        vue.createElementVNode("li", _hoisted_5, [
                            vue.createElementVNode("div", _hoisted_6, vue.toDisplayString(value.value), 1 /* TEXT */),
                            vue.withDirectives(vue.createElementVNode("input", {
                                id: _ctx.id,
                                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((value).value = $event)),
                                class: "form-pill-input w-100",
                                type: "text",
                                placeholder: vue.unref(items).length ? '' : __props.placeholder,
                                onBlur: _cache[1] || (_cache[1] = ($event) => (blur())),
                                onKeydown: _cache[2] || (_cache[2] = ($event) => (keydown($event))),
                                onPaste: _cache[3] || (_cache[3] = ($event) => (paste($event)))
                            }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_7), [
                                [vue.vModelText, value.value]
                            ])
                        ])
                    ])
                ], 8 /* PROPS */, _hoisted_1$5));
            };
        }
    });

    script$b.__file = "src/components/FormPills/FormPills.vue";

    const _hoisted_1$4 = ["disabled"];
    const _hoisted_2$3 = ["selected", "value"];
    var script$a = /*#__PURE__*/ vue.defineComponent({
        __name: 'FormSelect',
        props: formSelectProps,
        setup(__props) {
            const props = __props;
            const { classes } = useFormSelect(props);
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("select", {
                    class: vue.normalizeClass(["form-select", vue.unref(classes)]),
                    disabled: _ctx.disabled
                }, [
                    (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(_ctx.items, (item) => {
                        return (vue.openBlock(), vue.createElementBlock("option", {
                            key: item.value,
                            selected: item.selected,
                            value: item.value
                        }, vue.toDisplayString(item.label || item.value), 9 /* TEXT, PROPS */, _hoisted_2$3));
                    }), 128 /* KEYED_FRAGMENT */))
                ], 10 /* CLASS, PROPS */, _hoisted_1$4));
            };
        }
    });

    script$a.__file = "src/components/FormSelect/FormSelect.vue";

    const _hoisted_1$3 = {
        key: 0,
        class: "input-group-text"
    };
    const _hoisted_2$2 = {
        key: 0,
        class: "input-group-text"
    };
    var script$9 = /*#__PURE__*/ vue.defineComponent({
        __name: 'InputGroup',
        props: Object.assign({ append: {
                type: String,
                default: undefined,
            }, prepend: {
                type: String,
                default: undefined,
            } }, sizeProps),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                useSize(props.size, 'input-group-{0}').sizeClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    class: vue.normalizeClass(["input-group", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "prepend", {}, () => [
                        (__props.prepend)
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_1$3, vue.toDisplayString(__props.prepend), 1 /* TEXT */))
                            : vue.createCommentVNode("v-if", true)
                    ]),
                    vue.renderSlot(_ctx.$slots, "default"),
                    vue.renderSlot(_ctx.$slots, "append", {}, () => [
                        (__props.append)
                            ? (vue.openBlock(), vue.createElementBlock("span", _hoisted_2$2, vue.toDisplayString(__props.append), 1 /* TEXT */))
                            : vue.createCommentVNode("v-if", true)
                    ])
                ], 2 /* CLASS */));
            };
        }
    });

    script$9.__file = "src/components/InputGroup/InputGroup.vue";

    var script$8 = /*#__PURE__*/ vue.defineComponent({
        __name: 'ListGroup',
        props: Object.assign(Object.assign({}, flushProps), { horizontal: {
                type: Boolean,
                default: false,
            }, numbered: {
                type: Boolean,
                default: false,
            } }),
        setup(__props) {
            const props = __props;
            const tag = vue.computed(() => props.numbered ? 'ol' : 'ul');
            const { classes } = useClasses(vue.computed(() => [
                useFlush(props.flush, 'list-group-{0}').flushClass.value,
                props.horizontal ? 'list-group-horizontal' : undefined,
                props.numbered ? 'list-group-numbered' : undefined,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(vue.unref(tag)), {
                    class: vue.normalizeClass(["list-group", vue.unref(classes)])
                }, {
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["class"]));
            };
        }
    });

    script$8.__file = "src/components/ListGroup/ListGroup.vue";

    var script$7 = /*#__PURE__*/ vue.defineComponent({
        __name: 'ListGroupItem',
        props: Object.assign(Object.assign(Object.assign({}, activeProps), disabledProps), { tag: {
                type: String,
                default: 'li',
            }, variant: variantProp('') }),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                ['a', 'button'].includes(props.tag) ? 'list-group-item-action' : undefined,
                useActive(props.active).activeClass.value,
                useDisabled(props.disabled).disabledClass.value,
                useVariant(props.variant, 'list-group-item-{0}').variantClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.tag), {
                    class: vue.normalizeClass(["list-group-item", vue.unref(classes)])
                }, {
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["class"]));
            };
        }
    });

    script$7.__file = "src/components/ListGroupItem/ListGroupItem.vue";

    var script$6 = /*#__PURE__*/ vue.defineComponent({
        __name: 'Nav',
        props: {
            fill: {
                type: Boolean,
                default: false,
            },
            justified: {
                type: Boolean,
                default: false,
            },
            pills: {
                type: Boolean,
                default: false,
            },
            tabs: {
                type: Boolean,
                default: false,
            },
            vertical: {
                type: Boolean,
                default: false,
            },
        },
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                props.fill ? 'nav-fill' : undefined,
                props.justified ? 'nav-justified' : undefined,
                props.pills ? 'nav-pills' : undefined,
                props.tabs ? 'nav-tabs' : undefined,
                props.vertical ? 'flex-column' : undefined,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("nav", {
                    class: vue.normalizeClass(["nav", vue.unref(classes)])
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$6.__file = "src/components/Nav/Nav.vue";

    const _hoisted_1$2 = { class: "nav-item" };

    function render(_ctx, _cache) {
      return (vue.openBlock(), vue.createElementBlock("li", _hoisted_1$2, [
        vue.renderSlot(_ctx.$slots, "default")
      ]))
    }

    const script$5 = {};


    script$5.render = render;
    script$5.__file = "src/components/NavItem/NavItem.vue";

    var script$4 = /*#__PURE__*/ vue.defineComponent({
        __name: 'NavLink',
        props: Object.assign(Object.assign({}, activeProps), disabledProps),
        setup(__props) {
            const props = __props;
            const { classes } = useClasses(vue.computed(() => [
                useActive(props.active).activeClass.value,
                useDisabled(props.disabled).disabledClass.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("a", {
                    class: vue.normalizeClass(["nav-link", vue.unref(classes)]),
                    href: "#"
                }, [
                    vue.renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */));
            };
        }
    });

    script$4.__file = "src/components/NavLink/NavLink.vue";

    const placements = ['start', 'end', 'top', 'bottom'];
    var usePlacement = (placement, classTemplate) => {
        const { templatedString } = useStringTemplate(classTemplate, placement);
        return { placementClass: templatedString };
    };
    const placementProps = {
        placement: {
            type: String,
            default: 'start',
            validator: (v) => placements.includes(v),
        },
    };

    const _hoisted_1$1 = ["id", "data-bs-backdrop", "data-bs-scroll"];
    const _hoisted_2$1 = {
        key: 0,
        class: "offcanvas-header"
    };
    const offcanvasEvents = ['show', 'shown', 'hide', 'hidden'];
    var script$3 = /*#__PURE__*/ vue.defineComponent({
        __name: 'Offcanvas',
        props: Object.assign(Object.assign(Object.assign(Object.assign({ backdrop: {
                type: Boolean,
                default: true,
            }, header: {
                type: String,
                default: undefined,
            } }, idProps), { noBody: {
                type: Boolean,
                default: false,
            } }), placementProps), { scroll: {
                type: Boolean,
                default: false,
            }, show: {
                type: Boolean,
                default: false,
            } }),
        setup(__props, { expose, emit }) {
            const props = __props;
            const offcanvas = vue.ref();
            useBootstrapEmits(offcanvas, offcanvasEvents, emit, 'offcanvas');
            const { bsInstance: bsOffcanvas } = useBootstrapInstance('Offcanvas', offcanvas);
            const { classes } = useClasses(vue.computed(() => [
                usePlacement(props.placement, 'offcanvas-{0}').placementClass.value,
                vue.computed(() => props.show ? 'show' : undefined).value,
            ]));
            expose({ bsOffcanvas });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("div", {
                    id: _ctx.id,
                    ref_key: "offcanvas",
                    ref: offcanvas,
                    class: vue.normalizeClass(["offcanvas", vue.unref(classes)]),
                    "data-bs-backdrop": __props.backdrop,
                    "data-bs-scroll": __props.scroll
                }, [
                    (!!_ctx.$slots.header || !!__props.header)
                        ? (vue.openBlock(), vue.createElementBlock("div", _hoisted_2$1, [
                            vue.renderSlot(_ctx.$slots, "header", {}, () => [
                                vue.createTextVNode(vue.toDisplayString(__props.header), 1 /* TEXT */)
                            ])
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    vue.createElementVNode("div", {
                        class: vue.normalizeClass({ 'offcanvas-body': !__props.noBody })
                    }, [
                        vue.renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ], 10 /* CLASS, PROPS */, _hoisted_1$1));
            };
        }
    });

    script$3.__file = "src/components/Offcanvas/Offcanvas.vue";

    const aligns = ['baseline', 'center', 'end', 'start', 'stretch'];
    const alignProp = {
        type: String,
        default: undefined,
        validator: (a) => aligns.includes(a),
    };
    const gutterProp = {
        type: [Number, String],
        default: undefined,
    };
    const justifies = ['around', 'between', 'center', 'end', 'evenly', 'start'];
    const justifyProp = {
        type: String,
        default: undefined,
        validator: (j) => justifies.includes(j),
    };

    const tagProps = {
        tag: {
            type: String,
            default: 'div',
        },
    };

    const propsAlign = breakpointProps(alignProp, 'align-{0}');
    const propsCol = breakpointProps(colProp, 'cols-{0}');
    const propsGutters = breakpointProps(gutterProp, 'gutters-{0}');
    const propsGuttersX = breakpointProps(gutterProp, 'gutters-x-{0}');
    const propsGuttersY = breakpointProps(gutterProp, 'gutters-y-{0}');
    const propsJustify = breakpointProps(justifyProp, 'justify-{0}');
    var script$2 = /*#__PURE__*/ vue.defineComponent({
        __name: 'Row',
        props: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({ align: alignProp }, propsAlign), { cols: colProp }), propsCol), { gutters: gutterProp }), propsGutters), { guttersX: gutterProp }), propsGuttersX), { guttersY: gutterProp }), propsGuttersY), { justify: justifyProp }), propsJustify), tagProps),
        setup(__props) {
            const props = __props;
            const alignProps = {
                sm: vue.toRef(props, 'alignSm'),
                md: vue.toRef(props, 'alignMd'),
                lg: vue.toRef(props, 'alignLg'),
                xl: vue.toRef(props, 'alignXl'),
                xxl: vue.toRef(props, 'alignXxl'),
            };
            const alignClass = useStringTemplate('align-items-{0}', props.align).templatedString;
            const alignClasses = useBreakpoints(alignProps, 'align-items-{0}-{1}').breakpointClasses;
            const colProps = {
                sm: vue.toRef(props, 'colsSm'),
                md: vue.toRef(props, 'colsMd'),
                lg: vue.toRef(props, 'colsLg'),
                xl: vue.toRef(props, 'colsXl'),
                xxl: vue.toRef(props, 'colsXxl'),
            };
            const colClass = useStringTemplate('row-cols-{0}', props.cols).templatedString;
            const colClasses = useBreakpoints(colProps, 'row-cols-{0}-{1}').breakpointClasses;
            const guttersProps = {
                sm: vue.toRef(props, 'guttersSm'),
                md: vue.toRef(props, 'guttersMd'),
                lg: vue.toRef(props, 'guttersLg'),
                xl: vue.toRef(props, 'guttersXl'),
                xxl: vue.toRef(props, 'guttersXxl'),
            };
            const guttersClass = useStringTemplate('g-{0}', props.gutters).templatedString;
            const guttersClasses = useBreakpoints(guttersProps, 'g-{0}-{1}').breakpointClasses;
            const guttersXProps = {
                sm: vue.toRef(props, 'guttersXSm'),
                md: vue.toRef(props, 'guttersXMd'),
                lg: vue.toRef(props, 'guttersXLg'),
                xl: vue.toRef(props, 'guttersXXl'),
                xxl: vue.toRef(props, 'guttersXXxl'),
            };
            const guttersXClass = useStringTemplate('gx-{0}', props.guttersX).templatedString;
            const guttersXClasses = useBreakpoints(guttersXProps, 'gx-{0}-{1}').breakpointClasses;
            const guttersYProps = {
                sm: vue.toRef(props, 'guttersYSm'),
                md: vue.toRef(props, 'guttersYMd'),
                lg: vue.toRef(props, 'guttersYLg'),
                xl: vue.toRef(props, 'guttersYXl'),
                xxl: vue.toRef(props, 'guttersYXxl'),
            };
            const guttersYClass = useStringTemplate('gy-{0}', props.guttersY).templatedString;
            const guttersYClasses = useBreakpoints(guttersYProps, 'gy-{0}-{1}').breakpointClasses;
            const justifyProps = {
                sm: vue.toRef(props, 'justifySm'),
                md: vue.toRef(props, 'justifyMd'),
                lg: vue.toRef(props, 'justifyLg'),
                xl: vue.toRef(props, 'justifyXl'),
                xxl: vue.toRef(props, 'justifyXxl'),
            };
            const justifyClass = useStringTemplate('justify-content-{0}', props.justify).templatedString;
            const justifyClasses = useBreakpoints(justifyProps, 'justify-content-{0}-{1}').breakpointClasses;
            const { classes } = useClasses(vue.computed(() => [
                alignClass.value,
                ...alignClasses.value,
                colClass.value,
                ...colClasses.value,
                guttersClass.value,
                ...guttersClasses.value,
                guttersXClass.value,
                ...guttersXClasses.value,
                guttersYClass.value,
                ...guttersYClasses.value,
                justifyClass.value,
                ...justifyClasses.value,
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(_ctx.tag), {
                    class: vue.normalizeClass(["row", vue.unref(classes)])
                }, {
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["class"]));
            };
        }
    });

    script$2.__file = "src/components/Row/Row.vue";

    const _hoisted_1 = { key: 0 };
    const _hoisted_2 = ["onClick"];
    const _hoisted_3 = ["onClick"];
    var script$1 = /*#__PURE__*/ vue.defineComponent({
        __name: 'Table',
        props: {
            fields: {
                type: Array,
                required: false,
                default: undefined,
            },
            items: {
                type: Array,
                default: () => [],
            },
            multiSort: {
                type: Boolean,
                default: false,
            },
            hover: {
                type: Boolean,
                default: false,
            },
            // $attrs doesn't return emitted events so
            // we have to catch it as a prop
            // eslint-disable-next-line vue/prop-name-casing
            'onClick:row': {
                type: Function,
                default: undefined,
            },
        },
        emits: ["click:row", "sort"],
        setup(__props, { emit }) {
            const props = __props;
            const sorted = vue.ref((props.fields || [])
                .filter(f => f.sortable && f.sort)
                .reduce((obj, item) => Object.assign(obj, { [item.key]: item.sort }), {}));
            const headers = vue.computed(() => {
                if (props.fields) {
                    return props.fields;
                }
                const first = props.items.find(i => i !== undefined);
                return first
                    ? Object.keys(first)
                        .map(f => ({ key: f }))
                    : [];
            });
            const sort = (field) => {
                if (!field.sortable) {
                    return;
                }
                const key = field.key;
                const sort = sorted.value[key];
                if (props.multiSort) {
                    if (sort === 'asc') {
                        sorted.value[key] = 'desc';
                    }
                    else if (sort === 'desc') {
                        delete sorted.value[key];
                    }
                    else {
                        sorted.value[key] = 'asc';
                    }
                }
                else {
                    sorted.value = {
                        [key]: sort === 'asc' ? 'desc' : 'asc',
                    };
                }
                emit('sort', sorted.value);
            };
            const { classes } = useClasses(vue.computed(() => [
                props.hover && 'table-hover',
                props['onClick:row'] && 'table-click',
            ]));
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createElementBlock("table", {
                    class: vue.normalizeClass(["table", vue.unref(classes)])
                }, [
                    (vue.unref(headers).length)
                        ? (vue.openBlock(), vue.createElementBlock("thead", _hoisted_1, [
                            vue.createElementVNode("tr", null, [
                                (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(headers), (header) => {
                                    return vue.renderSlot(_ctx.$slots, `header-${header.key}`, {
                                        key: `header-${header.key}`,
                                        header: header
                                    }, () => [
                                        (vue.openBlock(), vue.createElementBlock("th", {
                                            key: header.key,
                                            class: vue.normalizeClass({
                                                'table-heading-sortable': header.sortable,
                                                'table-heading-sortable-asc': sorted.value[header.key] === 'asc',
                                                'table-heading-sortable-desc': sorted.value[header.key] === 'desc',
                                            }),
                                            onClick: ($event) => (sort(header))
                                        }, vue.toDisplayString(header.label || header.key), 11 /* TEXT, CLASS, PROPS */, _hoisted_2))
                                    ]);
                                }), 128 /* KEYED_FRAGMENT */))
                            ])
                        ]))
                        : vue.createCommentVNode("v-if", true),
                    vue.createElementVNode("tbody", null, [
                        vue.renderSlot(_ctx.$slots, "top-row"),
                        (!__props.items.length)
                            ? vue.renderSlot(_ctx.$slots, "no-items", { key: 0 })
                            : (vue.openBlock(true), vue.createElementBlock(vue.Fragment, { key: 1 }, vue.renderList(__props.items, (item, index) => {
                                return vue.renderSlot(_ctx.$slots, "row", {
                                    key: `item-${index}`,
                                    item: item,
                                    index: index
                                }, () => [
                                    vue.createElementVNode("tr", {
                                        onClick: ($event) => (_ctx.$emit('click:row', item))
                                    }, [
                                        (vue.openBlock(true), vue.createElementBlock(vue.Fragment, null, vue.renderList(vue.unref(headers), (header) => {
                                            return vue.renderSlot(_ctx.$slots, header.key, {
                                                key: header.key,
                                                item: item,
                                                index: index
                                            }, () => [
                                                (vue.openBlock(), vue.createElementBlock("td", {
                                                    key: `item-${index}-${header}`
                                                }, vue.toDisplayString(item[header.key]), 1 /* TEXT */))
                                            ]);
                                        }), 128 /* KEYED_FRAGMENT */))
                                    ], 8 /* PROPS */, _hoisted_3)
                                ]);
                            }), 128 /* KEYED_FRAGMENT */)),
                        vue.renderSlot(_ctx.$slots, "bottom-row")
                    ])
                ], 2 /* CLASS */));
            };
        }
    });

    script$1.__file = "src/components/Table/Table.vue";

    const tooltipFallbackPlacements = ['top', 'bottom', 'left', 'right'];
    const tooltipPlacements = [...tooltipFallbackPlacements, 'auto'];
    const tooltipFallbackPlacementProps = {
        fallbackPlacements: {
            type: Array,
            default: () => ['top', 'right', 'bottom', 'left'],
            validator: (v) => v.every(p => tooltipFallbackPlacements.includes(p)),
        },
    };
    const tooltipPlacementProps = {
        placement: {
            type: String,
            default: 'top',
            validator: (v) => tooltipPlacements.includes(v),
        },
    };

    const triggers = ['click', 'hover', 'focus', 'manual'];
    const triggerProps = {
        trigger: {
            type: [String, Array],
            default: ['hover', 'focus'],
            validator: (v) => {
                if (Array.isArray(v)) {
                    return v.every(t => triggers.includes(t));
                }
                return triggers.includes(v);
            },
        },
    };

    const tooltipEvents = ['show', 'shown', 'hide', 'hidden', 'inserted'];
    var script = /*#__PURE__*/ vue.defineComponent({
        __name: 'Tooltip',
        props: Object.assign(Object.assign(Object.assign({ boundary: {
                type: [String, HTMLElement],
                default: 'clippingParents',
            }, container: {
                type: [String, HTMLElement, Boolean],
                default: false,
            }, customClass: {
                type: [String, Array, Object],
                default: '',
            }, delay: {
                type: [Number, Object],
                default: 0,
            }, html: {
                type: Boolean,
                default: false,
            }, offset: {
                type: [String, Array],
                default: () => [0, 0],
            }, popperConfig: {
                type: [Object, Function],
                default: () => ({}),
            }, tag: {
                type: String,
                default: 'div',
            }, title: {
                type: String,
                default: '',
            } }, tooltipFallbackPlacementProps), tooltipPlacementProps), triggerProps),
        setup(__props, { expose, emit }) {
            const props = __props;
            const tooltip = vue.ref();
            const tooltipClass = vue.computed(() => {
                if (typeof props.customClass === 'string') {
                    return props.customClass;
                }
                if (Array.isArray(props.customClass)) {
                    return props.customClass.join(' ');
                }
                return Object.keys(props.customClass)
                    .filter((key) => !!props.customClass[key])
                    .join(' ');
            });
            const tooltipTriggers = vue.computed(() => {
                if (Array.isArray(props.trigger)) {
                    return props.trigger.join(' ');
                }
                return props.trigger;
            });
            useBootstrapEmits(tooltip, tooltipEvents, emit, 'tooltip');
            const { bsInstance: bsTooltip } = useBootstrapInstance('Tooltip', tooltip, Object.assign(Object.assign({}, props), { customClass: tooltipClass.value, trigger: tooltipTriggers.value }));
            expose({ bsTooltip });
            return (_ctx, _cache) => {
                return (vue.openBlock(), vue.createBlock(vue.resolveDynamicComponent(__props.tag), {
                    ref_key: "tooltip",
                    ref: tooltip
                }, {
                    default: vue.withCtx(() => [
                        vue.renderSlot(_ctx.$slots, "default")
                    ]),
                    _: 3 /* FORWARDED */
                }, 512 /* NEED_PATCH */));
            };
        }
    });

    script.__file = "src/components/Tooltip/Tooltip.vue";

    exports.Accordion = script$D;
    exports.AccordionItem = script$C;
    exports.Alert = script$B;
    exports.Badge = script$A;
    exports.Breadcrumb = script$z;
    exports.BreadcrumbItem = script$y;
    exports.Button = script$x;
    exports.ButtonClose = script$w;
    exports.ButtonGroup = script$v;
    exports.ButtonState = script$t;
    exports.Card = script$s;
    exports.Carousel = script$r;
    exports.Col = script$q;
    exports.Collapse = script$p;
    exports.Confirm = script$n;
    exports.Container = script$m;
    exports.Dropdown = script$j;
    exports.DropdownMenu = script$k;
    exports.DropdownMenuItem = script$l;
    exports.FormCheck = script$i;
    exports.FormCheckGroup = script$h;
    exports.FormControl = script$g;
    exports.FormDropdown = script$f;
    exports.FormDropdownSearch = script$e;
    exports.FormGroup = script$d;
    exports.FormImage = script$c;
    exports.FormPills = script$b;
    exports.FormSelect = script$a;
    exports.InputGroup = script$9;
    exports.ListGroup = script$8;
    exports.ListGroupItem = script$7;
    exports.Modal = script$o;
    exports.Nav = script$6;
    exports.NavItem = script$5;
    exports.NavLink = script$4;
    exports.Offcanvas = script$3;
    exports.Row = script$2;
    exports.Spinner = script$u;
    exports.Table = script$1;
    exports.Tooltip = script;
    exports.activeProps = activeProps;
    exports.breakpointProps = breakpointProps;
    exports.breakpoints = breakpoints;
    exports.colProp = colProp;
    exports.disabledProps = disabledProps;
    exports.dropdownItemsProps = dropdownItemsProps;
    exports.flushProps = flushProps;
    exports.formControlProps = formControlProps;
    exports.idProps = idProps;
    exports.sizeProps = sizeProps;
    exports.sizes = sizes;
    exports.tagProps = tagProps;
    exports.types = types;
    exports.useActive = useActive;
    exports.useBootstrap = useBootstrap;
    exports.useBootstrapEmits = useBootstrapEmits;
    exports.useBootstrapInstance = useBootstrapInstance;
    exports.useBreakpoints = useBreakpoints;
    exports.useClasses = useClasses;
    exports.useDisabled = useDisabled;
    exports.useFlush = useFlush;
    exports.useSize = useSize;
    exports.useStringTemplate = useStringTemplate;
    exports.useVariant = useVariant;
    exports.variantProp = variantProp;
    exports.variantProps = variantProps;
    exports.variants = variants;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
